# Python demos

- [dp_1d_quick.ipynb](https://github.com/cstarkjp/DPRS/tree/main/notebooks/dp_1d_quick.ipynb)


- [dp_1d.ipynb](https://github.com/cstarkjp/DPRS/tree/main/notebooks/dp_1d.ipynb)


- [dp_2d.ipynb](https://github.com/cstarkjp/DPRS/tree/main/notebooks/dp_2d.ipynb)

